@@ -60,22 +60,45 @@ class AccountInfo(AbstractModel):
         
 
 
-class DescribeRiskModelRequest(AbstractModel):
-    """DescribeRiskModel请求参数结构体
+class DescribeRiskAssessmentRequest(AbstractModel):
+    """DescribeRiskAssessment请求参数结构体
+
+    """
+
+
+class DescribeRiskAssessmentResponse(AbstractModel):
+    """DescribeRiskAssessment返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeRiskTrendsRequest(AbstractModel):
+    """DescribeRiskTrends请求参数结构体
 
     """
 
     def __init__(self):
         r"""
         :param BusinessSecurityData: 业务入参
-        :type BusinessSecurityData: :class:`tencentcloud.rce.v20201103.models.InputDescribeRiskModelData`
+        :type BusinessSecurityData: :class:`tencentcloud.rce.v20201103.models.InputFrontRisk`
         """
         self.BusinessSecurityData = None
 
 
     def _deserialize(self, params):
         if params.get("BusinessSecurityData") is not None:
-            self.BusinessSecurityData = InputDescribeRiskModelData()
+            self.BusinessSecurityData = InputFrontRisk()
             self.BusinessSecurityData._deserialize(params.get("BusinessSecurityData"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
@@ -86,15 +109,15 @@ class DescribeRiskModelRequest(AbstractModel):
         
 
 
-class DescribeRiskModelResponse(AbstractModel):
-    """DescribeRiskModel返回参数结构体
+class DescribeRiskTrendsResponse(AbstractModel):
+    """DescribeRiskTrends返回参数结构体
 
     """
 
     def __init__(self):
         r"""
         :param Data: 业务出参
-        :type Data: :class:`tencentcloud.rce.v20201103.models.OutputDescribeRiskModel`
+        :type Data: :class:`tencentcloud.rce.v20201103.models.OutputFrontRiskData`
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -104,34 +127,34 @@ class DescribeRiskModelResponse(AbstractModel):
 
     def _deserialize(self, params):
         if params.get("Data") is not None:
-            self.Data = OutputDescribeRiskModel()
+            self.Data = OutputFrontRiskData()
             self.Data._deserialize(params.get("Data"))
         self.RequestId = params.get("RequestId")
 
 
-class InputDescribeRiskModelData(AbstractModel):
-    """客户请求入参
+class InputCryptoManageMarketingRisk(AbstractModel):
+    """全栈式风控引擎入参
 
     """
 
     def __init__(self):
         r"""
-        :param UserData: 业务参数加密后的签名值
-        :type UserData: str
-        :param ApplyDate: 调用时间戳，精确到秒
-        :type ApplyDate: int
-        :param UserId: 客户业务侧标识用户的唯一ID
-        :type UserId: str
+        :param IsAuthorized: 是否授权
+        :type IsAuthorized: str
+        :param CryptoType: 加密类型
+        :type CryptoType: str
+        :param CryptoContent: 加密内容
+        :type CryptoContent: str
         """
-        self.UserData = None
-        self.ApplyDate = None
-        self.UserId = None
+        self.IsAuthorized = None
+        self.CryptoType = None
+        self.CryptoContent = None
 
 
     def _deserialize(self, params):
-        self.UserData = params.get("UserData")
-        self.ApplyDate = params.get("ApplyDate")
-        self.UserId = params.get("UserId")
+        self.IsAuthorized = params.get("IsAuthorized")
+        self.CryptoType = params.get("CryptoType")
+        self.CryptoContent = params.get("CryptoContent")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -169,6 +192,50 @@ class InputDetails(AbstractModel):
         
 
 
+class InputFrontRisk(AbstractModel):
+    """风险趋势统计--入参
+
+    """
+
+    def __init__(self):
+        r"""
+        :param EventId: 事件ID
+        :type EventId: int
+        :param StartTime: 开始时间
+        :type StartTime: str
+        :param EndTime: 结束时间
+        :type EndTime: str
+        :param Type: 趋势类型
+        :type Type: int
+        :param CurrentStartTime: 当前开始时间
+        :type CurrentStartTime: str
+        :param CurrentEndTime: 当前结束时间
+        :type CurrentEndTime: str
+        """
+        self.EventId = None
+        self.StartTime = None
+        self.EndTime = None
+        self.Type = None
+        self.CurrentStartTime = None
+        self.CurrentEndTime = None
+
+
+    def _deserialize(self, params):
+        self.EventId = params.get("EventId")
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.Type = params.get("Type")
+        self.CurrentStartTime = params.get("CurrentStartTime")
+        self.CurrentEndTime = params.get("CurrentEndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class InputManageMarketingRisk(AbstractModel):
     """全栈式风控引擎入参
 
@@ -224,6 +291,8 @@ class InputManageMarketingRisk(AbstractModel):
         :type Sponsor: :class:`tencentcloud.rce.v20201103.models.SponsorInfo`
         :param OnlineScam: 可选填写。详情请跳转至OnlineScamInfo查看。
         :type OnlineScam: :class:`tencentcloud.rce.v20201103.models.OnlineScamInfo`
+        :param Platform: 平台: 1android
+        :type Platform: str
         """
         self.Account = None
         self.SceneCode = None
@@ -246,6 +315,7 @@ class InputManageMarketingRisk(AbstractModel):
         self.Details = None
         self.Sponsor = None
         self.OnlineScam = None
+        self.Platform = None
 
 
     def _deserialize(self, params):
@@ -281,6 +351,7 @@ class InputManageMarketingRisk(AbstractModel):
         if params.get("OnlineScam") is not None:
             self.OnlineScam = OnlineScamInfo()
             self.OnlineScam._deserialize(params.get("OnlineScam"))
+        self.Platform = params.get("Platform")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -299,14 +370,20 @@ class ManageMarketingRiskRequest(AbstractModel):
         r"""
         :param BusinessSecurityData: 业务入参
         :type BusinessSecurityData: :class:`tencentcloud.rce.v20201103.models.InputManageMarketingRisk`
+        :param BusinessCryptoData: 业务入参
+        :type BusinessCryptoData: :class:`tencentcloud.rce.v20201103.models.InputCryptoManageMarketingRisk`
         """
         self.BusinessSecurityData = None
+        self.BusinessCryptoData = None
 
 
     def _deserialize(self, params):
         if params.get("BusinessSecurityData") is not None:
             self.BusinessSecurityData = InputManageMarketingRisk()
             self.BusinessSecurityData._deserialize(params.get("BusinessSecurityData"))
+        if params.get("BusinessCryptoData") is not None:
+            self.BusinessCryptoData = InputCryptoManageMarketingRisk()
+            self.BusinessCryptoData._deserialize(params.get("BusinessCryptoData"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -415,20 +492,57 @@ class OtherAccountInfo(AbstractModel):
         
 
 
-class OutputDescribeRiskModel(AbstractModel):
-    """业务出参
+class OutputFrontRisk(AbstractModel):
+    """风险趋势统计出参，需要为数组
 
     """
 
     def __init__(self):
         r"""
-        :param Code: 请求返回状态值，0为成功，别的结合Message查看
+        :param Name: 名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Name: str
+        :param Value: 参数值
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Value: list of OutputFrontRiskValue
+        """
+        self.Name = None
+        self.Value = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        if params.get("Value") is not None:
+            self.Value = []
+            for item in params.get("Value"):
+                obj = OutputFrontRiskValue()
+                obj._deserialize(item)
+                self.Value.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class OutputFrontRiskData(AbstractModel):
+    """风险趋势统计--出参
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Code: 返回码[0：成功；非0：标识失败错误码]。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Code: int
-        :param Message: 请求返回信息
+        :param Message: 出错消息[UTF-8编码]。
+注意：此字段可能返回 null，表示取不到有效值。
         :type Message: str
-        :param Value: 请求返回结果
-        :type Value: :class:`tencentcloud.rce.v20201103.models.OutputDescribeRiskModelValue`
+        :param Value: 返回结果。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Value: list of OutputFrontRisk
         """
         self.Code = None
         self.Message = None
@@ -439,8 +553,11 @@ class OutputDescribeRiskModel(AbstractModel):
         self.Code = params.get("Code")
         self.Message = params.get("Message")
         if params.get("Value") is not None:
-            self.Value = OutputDescribeRiskModelValue()
-            self.Value._deserialize(params.get("Value"))
+            self.Value = []
+            for item in params.get("Value"):
+                obj = OutputFrontRisk()
+                obj._deserialize(item)
+                self.Value.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -450,21 +567,27 @@ class OutputDescribeRiskModel(AbstractModel):
         
 
 
-class OutputDescribeRiskModelValue(AbstractModel):
-    """风控建模服务出参对应值
+class OutputFrontRiskValue(AbstractModel):
+    """风险趋势统计--值
 
     """
 
     def __init__(self):
         r"""
-        :param ApplyScore: 模型分数值
-        :type ApplyScore: float
+        :param Requests: 请求次数
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Requests: int
+        :param Index: 日期标签
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Index: str
         """
-        self.ApplyScore = None
+        self.Requests = None
+        self.Index = None
 
 
     def _deserialize(self, params):
-        self.ApplyScore = params.get("ApplyScore")
+        self.Requests = params.get("Requests")
+        self.Index = params.get("Index")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -575,6 +698,9 @@ reject：拒绝，高风险恶意
 2063 疑似 群控设备 请求设备为猫池、手机墙等群控设备
 注意：此字段可能返回 null，表示取不到有效值。
         :type RiskType: list of int
+        :param ConstId: 唯一ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ConstId: str
         """
         self.UserId = None
         self.PostTime = None
@@ -582,6 +708,7 @@ reject：拒绝，高风险恶意
         self.UserIp = None
         self.RiskLevel = None
         self.RiskType = None
+        self.ConstId = None
 
 
     def _deserialize(self, params):
@@ -591,6 +718,7 @@ reject：拒绝，高风险恶意
         self.UserIp = params.get("UserIp")
         self.RiskLevel = params.get("RiskLevel")
         self.RiskType = params.get("RiskType")
+        self.ConstId = params.get("ConstId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
